@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2021-07-01
+# Release 2022-04-19
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.5.1
+MAKERESOLVEDEB_VERSION=1.6.0
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -113,7 +113,7 @@ close_deb() {
     chmod 755 ${DEB_DIR}/DEBIAN/postrm
 }
 
-process15() {
+process_15() {
     # Create directories
     create_directory ${RESOLVE_BASE_DIR}/configs
     create_directory ${RESOLVE_BASE_DIR}/easyDCP
@@ -154,35 +154,6 @@ process15() {
     create_directory ${DEB_DIR}/usr/lib/
     extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib/ libDaVinciPanelAPI.so
 
-    # Create desktop shortcuts
-    assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Resolve.png
-    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}.desktop <<EOF
-[Desktop Entry]
-Version=1.0
-Encoding=UTF-8
-Exec=/opt/resolve/bin/resolve
-Icon=/opt/resolve/graphics/DV_Resolve.png
-Name=${RESOLVE_NAME}
-Terminal=false
-MimeType=application/x-resolveproj;
-Type=Application
-StartupNotify=true
-Categories=AudioVideo
-EOF
-    assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Panels.png
-    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-panel-setup.desktop <<EOF
-[Desktop Entry]
-Version=1.0
-Encoding=UTF-8
-Exec="/opt/resolve/DaVinci Resolve Panels Setup/DaVinci Resolve Panels Setup"
-Icon=/opt/resolve/graphics/DV_Panels.png
-Name=DaVinci Resolve Panels Setup
-Terminal=false
-Type=Application
-StartupNotify=true
-Categories=AudioVideo
-EOF
-
     # Add postinst commands
     cat >> ${DEB_DIR}/DEBIAN/postinst <<EOF
 test -e /opt/resolve/configs/config.dat || cp /opt/resolve/configs/config.dat-pkg-default /opt/resolve/configs/config.dat
@@ -203,7 +174,7 @@ chmod -R a+rw /opt/resolve/Media
 EOF
 }
 
-process16() {
+process_16() {
     # Create directories
     create_directory ${RESOLVE_BASE_DIR}/easyDCP
     create_directory ${RESOLVE_BASE_DIR}/scripts
@@ -248,35 +219,6 @@ process16() {
     # Create common data dir
     create_directory ${DEB_DIR}/var/BlackmagicDesign/DaVinci\ Resolve
 
-    # Create desktop shortcuts
-    assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Resolve.png
-    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}.desktop <<EOF
-[Desktop Entry]
-Version=1.0
-Encoding=UTF-8
-Exec=/opt/resolve/bin/resolve
-Icon=/opt/resolve/graphics/DV_Resolve.png
-Name=${RESOLVE_NAME}
-Terminal=false
-MimeType=application/x-resolveproj;
-Type=Application
-StartupNotify=true
-Categories=AudioVideo
-EOF
-    assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Panels.png
-    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-panel-setup.desktop <<EOF
-[Desktop Entry]
-Version=1.0
-Encoding=UTF-8
-Exec="/opt/resolve/DaVinci Resolve Panels Setup/DaVinci Resolve Panels Setup"
-Icon=/opt/resolve/graphics/DV_Panels.png
-Name=DaVinci Resolve Panels Setup
-Terminal=false
-Type=Application
-StartupNotify=true
-Categories=AudioVideo
-EOF
-
     # Add postinst commands
     cat >> ${DEB_DIR}/DEBIAN/postinst <<EOF
 chmod -R a+rw /opt/resolve/easyDCP
@@ -297,7 +239,7 @@ EOF
     fi
 }
 
-process17() {
+process_17() {
     # Create directories
     create_directory ${RESOLVE_BASE_DIR}/easyDCP
     create_directory ${RESOLVE_BASE_DIR}/scripts
@@ -344,34 +286,59 @@ process17() {
     # Create common data dir
     create_directory ${DEB_DIR}/var/BlackmagicDesign/DaVinci\ Resolve
 
-    # Create desktop shortcuts
-    assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Resolve.png
-    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}.desktop <<EOF
-[Desktop Entry]
-Version=1.0
-Encoding=UTF-8
-Exec=/opt/resolve/bin/resolve
-Icon=/opt/resolve/graphics/DV_Resolve.png
-Name=${RESOLVE_NAME}
-Terminal=false
-MimeType=application/x-resolveproj;
-Type=Application
-StartupNotify=true
-Categories=AudioVideo
-EOF
-    assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Panels.png
-    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-panel-setup.desktop <<EOF
-[Desktop Entry]
-Version=1.0
-Encoding=UTF-8
-Exec="/opt/resolve/DaVinci Control Panels Setup/DaVinci Control Panels Setup"
-Icon=/opt/resolve/graphics/DV_Panels.png
-Name=DaVinci Control Panels Setup
-Terminal=false
-Type=Application
-StartupNotify=true
-Categories=AudioVideo
+    # Add postinst commands
+    cat >> ${DEB_DIR}/DEBIAN/postinst <<EOF
+chmod -R a+rw /opt/resolve/easyDCP
+chmod -R a+rw /opt/resolve/LUT
+chmod -R a+rw /opt/resolve/.license
+chmod -R a+rw /opt/resolve/Fairlight
+chmod -R a+rw /var/BlackmagicDesign/"DaVinci Resolve"
 EOF
+}
+
+process_18() {
+    # Create directories
+    create_directory ${RESOLVE_BASE_DIR}/easyDCP
+    create_directory ${RESOLVE_BASE_DIR}/scripts
+    create_directory ${RESOLVE_BASE_DIR}/.license
+    create_directory ${RESOLVE_BASE_DIR}/share
+    create_directory ${RESOLVE_BASE_DIR}/Fairlight
+
+    # Copy objects
+    copy_object ${UNPACK_DIR}/bin ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/Control ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/Certificates ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/DaVinci\ Control\ Panels\ Setup ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/Developer ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/docs ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/Fairlight\ Studio\ Utility ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/Fusion ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/graphics ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/libs ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/LUT ${RESOLVE_BASE_DIR}
+    if [[ -z "$SKIP_ONBOARDING" ]]; then
+	copy_object ${UNPACK_DIR}/Onboarding ${RESOLVE_BASE_DIR}
+    fi
+    copy_object ${UNPACK_DIR}/plugins ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/Technical\ Documentation ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/UI_Resource ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/scripts/script.checkfirmware ${RESOLVE_BASE_DIR}/scripts/
+    copy_object ${UNPACK_DIR}/scripts/script.getlogs.v4 ${RESOLVE_BASE_DIR}/scripts/
+    copy_object ${UNPACK_DIR}/scripts/script.start ${RESOLVE_BASE_DIR}/scripts/
+    copy_object ${UNPACK_DIR}/share/default-config.dat ${RESOLVE_BASE_DIR}/share/
+    copy_object ${UNPACK_DIR}/share/default_cm_config.bin ${RESOLVE_BASE_DIR}/share/
+    copy_object ${UNPACK_DIR}/share/log-conf.xml ${RESOLVE_BASE_DIR}/share/
+    if [[ -e ${UNPACK_DIR}/share/remote-monitoring-log-conf.xml ]]; then
+	copy_object ${UNPACK_DIR}/share/remote-monitoring-log-conf.xml ${RESOLVE_BASE_DIR}/share/
+    fi
+    
+    # Extract panel API library
+    create_directory ${DEB_DIR}/usr/lib
+    extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib libDaVinciPanelAPI.so
+    extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib libFairlightPanelAPI.so
+
+    # Create common data dir
+    create_directory ${DEB_DIR}/var/BlackmagicDesign/DaVinci\ Resolve
 
     # Add postinst commands
     cat >> ${DEB_DIR}/DEBIAN/postinst <<EOF
@@ -383,54 +350,141 @@ chmod -R a+rw /var/BlackmagicDesign/"DaVinci Resolve"
 EOF
 }
 
-process1617braw() {
+process_braw() {
     if [[ ! -z "$SKIP_BRAW" ]]; then
 	return;
     fi
-    if [[ ! -e ${UNPACK_DIR}/BlackmagicRAWPlayer ]]; then
-	return;
-    fi
-    echo "Adding BlackmagicRAWPlayer"
-
-    copy_object ${UNPACK_DIR}/BlackmagicRAWPlayer ${RESOLVE_BASE_DIR}
-
-    assert_object ${DEB_DIR}/opt/resolve/graphics/blackmagicraw-player_256x256_apps.png
-    assert_object ${DEB_DIR}/opt/resolve/BlackmagicRAWPlayer/BlackmagicRAWPlayer
-    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-braw-player.desktop <<EOF
+    if [[ -e ${UNPACK_DIR}/BlackmagicRAWPlayer ]]; then
+	echo "Adding BlackmagicRAWPlayer"
+	
+	copy_object ${UNPACK_DIR}/BlackmagicRAWPlayer ${RESOLVE_BASE_DIR}
+	
+	assert_object ${DEB_DIR}/opt/resolve/graphics/blackmagicraw-player_256x256_apps.png
+	assert_object ${DEB_DIR}/opt/resolve/BlackmagicRAWPlayer/BlackmagicRAWPlayer
+	cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-braw-player.desktop <<EOF
 [Desktop Entry]
 Version=1.0
 Encoding=UTF-8
+Type=Application
+Name=Blackmagic RAW Player
 Exec=/opt/resolve/BlackmagicRAWPlayer/BlackmagicRAWPlayer
 Icon=/opt/resolve/graphics/blackmagicraw-player_256x256_apps.png
-Name=Blackmagic RAW Player
 Terminal=false
 MimeType=application/x-braw-clip;application/x-braw-sidecar
-Type=Application
 StartupNotify=true
 Categories=AudioVideo
 EOF
-
-    if [[ ! -e ${UNPACK_DIR}/BlackmagicRAWSpeedTest ]]; then
-	return;
     fi
-    echo "Adding BlackmagicRAWSpeedTest"
-
-    copy_object ${UNPACK_DIR}/BlackmagicRAWSpeedTest ${RESOLVE_BASE_DIR}
-
-    assert_object ${DEB_DIR}/opt/resolve/graphics/blackmagicraw-speedtest_256x256_apps.png
-    assert_object ${DEB_DIR}/opt/resolve/BlackmagicRAWSpeedTest/BlackmagicRAWSpeedTest
-    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-braw-speedtest.desktop <<EOF
+    
+    if [[ -e ${UNPACK_DIR}/BlackmagicRAWSpeedTest ]]; then
+	echo "Adding BlackmagicRAWSpeedTest"
+	
+	copy_object ${UNPACK_DIR}/BlackmagicRAWSpeedTest ${RESOLVE_BASE_DIR}
+	
+	assert_object ${DEB_DIR}/opt/resolve/graphics/blackmagicraw-speedtest_256x256_apps.png
+	assert_object ${DEB_DIR}/opt/resolve/BlackmagicRAWSpeedTest/BlackmagicRAWSpeedTest
+	cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-braw-speedtest.desktop <<EOF
 [Desktop Entry]
 Version=1.0
 Encoding=UTF-8
+Type=Application
+Name=Blackmagic RAW Speed Test
 Exec=/opt/resolve/BlackmagicRAWSpeedTest/BlackmagicRAWSpeedTest
 Icon=/opt/resolve/graphics/blackmagicraw-speedtest_256x256_apps.png
-Name=Blackmagic RAW Speed Test
 Terminal=false
-Type=Application
 StartupNotify=true
 Categories=AudioVideo
 EOF
+    fi
+}
+
+process_udev() {
+    # Create udev rules
+    create_directory ${DEB_DIR}/lib/udev/rules.d
+    cat > ${DEB_DIR}/lib/udev/rules.d/75-davincipanel.rules <<EOF
+SUBSYSTEM=="usb", ATTRS{idVendor}=="1edb", MODE="0666"
+EOF
+    cat > ${DEB_DIR}/lib/udev/rules.d/75-davincikb.rules <<EOF
+SUBSYSTEMS=="usb", ENV{.LOCAL_ifNum}="\$attr{bInterfaceNumber}"
+# Editor Keyboard
+SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0b", ENV{.LOCAL_ifNum}=="04", MODE="0666"
+# Speed Editor Keyboard
+SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0e", ENV{.LOCAL_ifNum}=="02", MODE="0666"
+EOF
+    cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
+SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
+EOF
+    # Add postinst commands
+    cat >> ${DEB_DIR}/DEBIAN/postinst <<EOF
+udevadm control --reload-rules
+udevadm trigger
+EOF
+}
+
+process_desktop_shortcuts() {
+    assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Resolve.png
+    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}.desktop <<EOF
+[Desktop Entry]
+Version=1.0
+Encoding=UTF-8
+Type=Application
+Name=${RESOLVE_NAME}
+Path=/opt/resolve
+Exec=/opt/resolve/bin/resolve
+Icon=/opt/resolve/graphics/DV_Resolve.png
+Terminal=false
+MimeType=application/x-resolveproj;
+StartupNotify=true
+Categories=AudioVideo
+EOF
+    if [[ -e "${DEB_DIR}/opt/resolve/DaVinci Resolve Panels Setup/DaVinci Resolve Panels Setup" ]]; then
+	assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Panels.png
+	cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-panel-setup.desktop <<EOF
+[Desktop Entry]
+Version=1.0
+Encoding=UTF-8
+Type=Application
+Name=DaVinci Resolve Panels Setup
+Path=/opt/resolve
+Exec="/opt/resolve/DaVinci Resolve Panels Setup/DaVinci Resolve Panels Setup"
+Icon=/opt/resolve/graphics/DV_Panels.png
+Terminal=false
+StartupNotify=true
+Categories=AudioVideo
+EOF
+    fi
+    if [[ -e "${DEB_DIR}/opt/resolve/DaVinci Control Panels Setup/DaVinci Control Panels Setup" ]]; then
+	assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Panels.png
+	cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-panel-setup.desktop <<EOF
+[Desktop Entry]
+Version=1.0
+Encoding=UTF-8
+Type=Application
+Name=DaVinci Control Panels Setup
+Path=/opt/resolve
+Exec="/opt/resolve/DaVinci Control Panels Setup/DaVinci Control Panels Setup"
+Icon=/opt/resolve/graphics/DV_Panels.png
+Terminal=false
+StartupNotify=true
+Categories=AudioVideo
+EOF
+    fi
+    if [[ -e "${DEB_DIR}/opt/resolve/bin/DaVinci Remote Monitoring" ]]; then
+	assert_object ${DEB_DIR}/opt/resolve/graphics/Remote_Monitoring.png
+	cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-remote-monitoring.desktop <<EOF
+[Desktop Entry]
+Version=1.0
+Encoding=UTF-8
+Type=Application
+Name=DaVinci Remote Monitoring
+Path=/opt/resolve
+Exec="/opt/resolve/bin/DaVinci Remote Monitoring"
+Icon=/opt/resolve/graphics/Remote_Monitoring.png
+Terminal=false
+StartupNotify=true
+Categories=AudioVideo
+EOF
+    fi
 }
 
 installer_extract_xorriso() {
@@ -467,29 +521,6 @@ installer_extract_native() {
     fi
 }
 
-processudev() {
-    # Create udev rules
-    create_directory ${DEB_DIR}/lib/udev/rules.d
-    cat > ${DEB_DIR}/lib/udev/rules.d/75-davincipanel.rules <<EOF
-SUBSYSTEM=="usb", ATTRS{idVendor}=="1edb", MODE="0666"
-EOF
-    cat > ${DEB_DIR}/lib/udev/rules.d/75-davincikb.rules <<EOF
-SUBSYSTEMS=="usb", ENV{.LOCAL_ifNum}="\$attr{bInterfaceNumber}"
-# Editor Keyboard
-SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0b", ENV{.LOCAL_ifNum}=="04", MODE="0666"
-# Speed Editor Keyboard
-SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0e", ENV{.LOCAL_ifNum}=="02", MODE="0666"
-EOF
-    cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
-SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
-EOF
-    # Add postinst commands
-    cat >> ${DEB_DIR}/DEBIAN/postinst <<EOF
-udevadm control --reload-rules
-udevadm trigger
-EOF
-}
-
 print_usage() {
     echo "Usage: $0 <DaVinci_Resolve_*_Linux.run>"
     echo "Advanced options:"
@@ -605,44 +636,59 @@ case $RESOLVE_VERSION in
     15.*)
 	echo "Using Resolve 15 conversion process"
 	installer_extract_xorriso
-	process15
-	processudev
+	process_15
+	process_udev
+	process_desktop_shortcuts
 	;;
     16.*)
 	echo "Using Resolve 16 conversion process"
 	installer_extract_native
-	process16
-	process1617braw
-	processudev
+	process_16
+	process_braw
+	process_udev
+	process_desktop_shortcuts
 	;;
     17.*)
 	echo "Using Resolve 17 conversion process"
 	installer_extract_native
-	process17
-	process1617braw
-	processudev
+	process_17
+	process_braw
+	process_udev
+	process_desktop_shortcuts
+	;;
+    18.*)
+	echo "Using Resolve 18 conversion process"
+	installer_extract_native
+	process_18
+	process_braw
+	process_udev
+	process_desktop_shortcuts
 	;;
     *)
 	echo "Unknown Resolve version"
-	echo "Trying Resolve 17 conversion process"
+	echo "Trying Resolve 18 conversion process"
 	installer_extract_native
-	process17
-	process1617braw
-	processudev
+	process_18
+	process_braw
+	process_udev
+	process_desktop_chortcuts
 	;;
 esac
 
-# Create Debian package
+# Finalize Debian package
 close_deb
-echo "Creating Debian package"
-if ! fakeroot dpkg-deb -b ${DEB_DIR} ${DEB_DIR}.deb;
-then
-    ERRORS=$((ERRORS+1))
-fi
 
-# Clean up
-remove_directory ${UNPACK_DIR}
-remove_directory ${DEB_DIR}
+if [[ -z "$CI_TEST" ]]; then
+    echo "Creating Debian package"
+    if ! fakeroot dpkg-deb -b ${DEB_DIR} ${DEB_DIR}.deb;
+    then
+	ERRORS=$((ERRORS+1))
+    fi
+    
+    # Clean up
+    remove_directory ${UNPACK_DIR}
+    remove_directory ${DEB_DIR}
+fi
 
 # Report
 echo
